@@ -29,7 +29,6 @@ pkg.require({ 'cairo': '1.0',
               'GeocodeGlib': '1.0',
               'Gdk': '3.0',
               'GdkPixbuf': '2.0',
-              'GFBGraph': '0.2',
               'Gio': '2.0',
               'GLib': '2.0',
               'Goa': '1.0',
@@ -39,7 +38,8 @@ pkg.require({ 'cairo': '1.0',
               'GtkClutter': '1.0',
               'Handy': '1',
               'Rest': '0.7',
-              'Soup': '2.4' });
+              'Soup': '2.4',
+              'WebKit2': '4.0' });
 
 const Application = imports.application;
 
