@@ -22,11 +22,13 @@
 const _ = imports.gettext.gettext;
 
 const Geocode = imports.gi.GeocodeGlib;
+const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 
 const Location = imports.location;
 const Overpass = imports.overpass;
+const PlaceIcons = imports.placeIcons;
 const URLS = imports.urls;
 const Utils = imports.utils;
 
@@ -55,6 +57,9 @@ class Place extends Geocode.Place {
         this._website = params.website;
         delete params.website;
 
+        this._email = params.email;
+        delete params.email;
+
         this._phone = params.phone;
         delete params.phone;
 
@@ -73,6 +78,9 @@ class Place extends Geocode.Place {
         this._toilets = params.toilets;
         delete params.toilets;
 
+        this._takeaway = params.takeaway;
+        delete params.takeaway;
+
         this._note = params.note;
         delete params.note;
 
@@ -100,6 +108,12 @@ class Place extends Geocode.Place {
         this._nativeName = params.nativeName;
         delete params.nativeName;
 
+        this._osmKey = params.osmKey;
+        delete params.osmKey;
+
+        this._osmValue = params.osmValue;
+        delete params.osmValue;
+
         if (params.place) {
             params = { osm_id: params.place.osm_id,
                        osm_type: params.place.osm_type,
@@ -159,6 +173,14 @@ class Place extends Geocode.Place {
         return this._website;
     }
 
+    set email(v) {
+        this._email = v;
+    }
+
+    get email() {
+        return this._email;
+    }
+
     set phone(v) {
         this._phone = v;
     }
@@ -207,6 +229,14 @@ class Place extends Geocode.Place {
         return this._toilets;
     }
 
+    set takeaway(v) {
+        this._takeaway = v;
+    }
+
+    get takeaway() {
+        return this._takeaway;
+    }
+
     set note(v) {
         this._note = v;
     }
@@ -243,6 +273,40 @@ class Place extends Geocode.Place {
         this._nativeName = nativeName;
     }
 
+    /**
+     * Most important OSM tag for the place ('amenity', 'shop', and so on).
+     * This corresponds to the osm_key parameter in Photon geocoder
+     */
+    get osmKey() {
+        return this._osmKey;
+    }
+
+    /**
+     * Value for the most important OSM tag.
+     * This corresponds to the osm_value parameter in Photon geocoder.
+     */
+    get osmValue() {
+        return this._osmValue;
+    }
+
+    get icon() {
+        return Gio.Icon.new_for_string(this._getIconName());
+    }
+
+    _getIconName() {
+        return PlaceIcons.getIconForPlace(this);
+    }
+
+    /**
+     * This property is true for places related to eating and/or drinking,
+     * such as restaurants, cafes, pubs and similar
+     */
+    get isEatingAndDrinking() {
+        return this._osmKey === 'amenity' &&
+               ['bar', 'biergarten', 'cafe', 'fast_food', 'food_court',
+                'restaurant', 'pub'].indexOf(this._osmValue) !== -1;
+    }
+
     toJSON() {
         let bounding_box = null;
 
@@ -260,6 +324,8 @@ class Place extends Geocode.Place {
 
         return { id: this.osm_id,
                  osm_type: this.osm_type,
+                 osmKey: this._osmKey,
+                 osmValue: this._osmValue,
                  place_type: this.place_type,
                  name: this.name,
                  nativeName: this.nativeName,
@@ -279,6 +345,7 @@ class Place extends Geocode.Place {
                  continent: this.continent,
                  population: this.population,
                  website: this.website,
+                 email: this.email,
                  phone: this.phone,
                  wiki: this.wiki,
                  wheelchair: this.wheelchair,
@@ -286,6 +353,7 @@ class Place extends Geocode.Place {
                  internetAccess: this.internetAccess,
                  religion: this.religion,
                  toilets: this.toilets,
+                 takeaway: this.takeaway,
                  note: this.note };
     }
 
