@@ -22,7 +22,6 @@
 const GObject = imports.gi.GObject;
 
 const MapMarker = imports.mapMarker;
-const PlaceBubble = imports.placeBubble;
 
 var PlaceMarker = GObject.registerClass(
 class PlaceMarker extends MapMarker.MapMarker {
@@ -38,11 +37,7 @@ class PlaceMarker extends MapMarker.MapMarker {
                  y: this.height - 3 };
     }
 
-    _createBubble() {
-        if (this.place.name) {
-            return new PlaceBubble.PlaceBubble({ place: this.place,
-                                                 mapView: this._mapView });
-        } else
-            return null;
+    _hasBubble() {
+        return true;
     }
 });
